diff --git a/internal/app/api/html_test.go b/internal/app/api/html_test.go
index 9a079a99..8ee252b9 100644
--- a/internal/app/api/html_test.go
+++ b/internal/app/api/html_test.go
@@ -11,7 +11,7 @@ import (
)
func TestHTML(t *testing.T) {
- body, contentType := test.HTMLMultipartForm(t)
+ body, contentType := test.HTMLTestMultipartForm(t)
req := httptest.NewRequest(http.MethodPost, "/convert/html", body)
req.Header.Set(echo.HeaderContentType, contentType)
rec := httptest.NewRecorder()
diff --git a/internal/app/api/markdown_test.go b/internal/app/api/markdown_test.go
index 9163b33c..a399d58a 100644
--- a/internal/app/api/markdown_test.go
+++ b/internal/app/api/markdown_test.go
@@ -11,7 +11,7 @@ import (
)
func TestMarkdown(t *testing.T) {
- body, contentType := test.MarkdownMultipartForm(t)
+ body, contentType := test.MarkdownTestMultipartForm(t)
req := httptest.NewRequest(http.MethodPost, "/convert/markdown", body)
req.Header.Set(echo.HeaderContentType, contentType)
rec := httptest.NewRecorder()
diff --git a/internal/app/api/merge_test.go b/internal/app/api/merge_test.go
index bdc57016..4d147887 100644
--- a/internal/app/api/merge_test.go
+++ b/internal/app/api/merge_test.go
@@ -11,7 +11,7 @@ import (
)
func TestMerge(t *testing.T) {
- body, contentType := test.PDFMultipartForm(t)
+ body, contentType := test.PDFTestMultipartForm(t)
req := httptest.NewRequest(http.MethodPost, "/merge", body)
req.Header.Set(echo.HeaderContentType, contentType)
rec := httptest.NewRecorder()
diff --git a/internal/app/api/office_test.go b/internal/app/api/office_test.go
index 49c8f7f4..a46c4c8f 100644
--- a/internal/app/api/office_test.go
+++ b/internal/app/api/office_test.go
@@ -11,7 +11,7 @@ import (
)
func TestOffice(t *testing.T) {
- body, contentType := test.OfficeMultipartForm(t)
+ body, contentType := test.OfficeTestMultipartForm(t)
req := httptest.NewRequest(http.MethodPost, "/convert/office", body)
req.Header.Set(echo.HeaderContentType, contentType)
rec := httptest.NewRecorder()
diff --git a/pkg/doc.go b/pkg/doc.go
index 9792a3e8..022b107b 100644
--- a/pkg/doc.go
+++ b/pkg/doc.go
@@ -17,9 +17,9 @@ For instance, if you want to convert HTML:
},
Options: &gotenberg.HTMLOptions{
HeaderFilePath: "header.html",
- FooterFilePath: "footer.html",
- PaperSize: gotenberg.A4,
- PaperMargins: gotenberg.NormalMargins,
+ FooterFilePath: "footer.html",
+ PaperSize: gotenberg.A4,
+ PaperMargins: gotenberg.NormalMargins,
},
}
dest := "foo.pdf"
diff --git a/test/testfunc.go b/test/testfunc.go
index 3de6fe86..f6235281 100644
--- a/test/testfunc.go
+++ b/test/testfunc.go
@@ -16,31 +16,31 @@ import (
"github.com/thecodingmachine/gotenberg/internal/pkg/rand"
)
-// HTMLMultipartForm returns the body
+// HTMLTestMultipartForm returns the body
// for a multipate/form-data request with all
// files under "html" folder.
-func HTMLMultipartForm(t *testing.T) (*bytes.Buffer, string) {
+func HTMLTestMultipartForm(t *testing.T) (*bytes.Buffer, string) {
return multipartForm(t, "html")
}
// MarkdownMultipartForm returns the body
// for a multipate/form-data request with all
// files under "markdown" folder.
-func MarkdownMultipartForm(t *testing.T) (*bytes.Buffer, string) {
+func MarkdownTestMultipartForm(t *testing.T) (*bytes.Buffer, string) {
return multipartForm(t, "markdown")
}
// OfficeMultipartForm returns the body
// for a multipate/form-data request with all
// files under "office" folder.
-func OfficeMultipartForm(t *testing.T) (*bytes.Buffer, string) {
+func OfficeTestMultipartForm(t *testing.T) (*bytes.Buffer, string) {
return multipartForm(t, "office")
}
-// PDFMultipartForm returns the body
+// PDFTestMultipartForm returns the body
// for a multipate/form-data request with all
// files under "pdf" folder.
-func PDFMultipartForm(t *testing.T) (*bytes.Buffer, string) {
+func PDFTestMultipartForm(t *testing.T) (*bytes.Buffer, string) {
return multipartForm(t, "pdf")
}
@@ -16,31 +16,31 @@ import (
return multipartForm(t, "html")
}
-// MarkdownMultipartForm returns the body
+// MarkdownTestMultipartForm returns the body
// for a multipate/form-data request with all
// files under "markdown" folder.
@@ -16,31 +16,31 @@ import (
return multipartForm(t, "markdown")
}
-// OfficeMultipartForm returns the body
+// OfficeTestMultipartForm returns the body
// for a multipate/form-data request with all
// files under "office" folder.